@@ -3,8 +3,14 @@ from mc.net.minecraft.level.tile.Tiles import SoundType, tiles
 class GameMode:
 
     def __init__(self, minecraft):
-        self._mc = minecraft
-        self.isInTestMode = False
+        self._minecraft = minecraft
+        self.mode = False
+
+    def initLevel(self, level):
+        level.creativeMode = False
+
+    def handleOpenInventory(self):
+        pass
 
     def startDestroyBlock(self, x, y, z):
         self.destroyBlock(x, y, z)
@@ -13,23 +19,24 @@ class GameMode:
         return True
 
     def destroyBlock(self, x, y, z):
-        tile = tiles.tiles[self._mc.level.getTile(x, y, z)]
-        change = self._mc.level.netSetTile(x, y, z, 0)
+        tile = tiles.tiles[self._minecraft.level.getTile(x, y, z)]
+        change = self._minecraft.level.netSetTile(x, y, z, 0)
         if tile and change:
-            if self._mc.isOnlineClient():
-                self._mc.networkClient.sendTileUpdated(x, y, z, 0, self._mc.player.inventory.getSelected())
+            if self._minecraft.isOnlineClient():
+                self._minecraft.networkClient.sendTileUpdated(x, y, z, 0,
+                                                              self._minecraft.player.inventory.getSelected())
             if tile.soundType != SoundType.none:
-                self._mc.level.playSound('step.' + tile.soundType.soundName,
+                self._minecraft.level.playSound('step.' + tile.soundType.soundName,
                                          x, y, z,
                                          (tile.soundType.getVolume() + 1.0) / 2.0,
                                          tile.soundType.getPitch() * 0.8)
 
-            tile.destroy(self._mc.level, x, y, z, self._mc.particleEngine)
+            tile.destroy(self._minecraft.level, x, y, z, self._minecraft.particleEngine)
 
-    def stopDestroyingBlock(self, x, y, z, sideHit):
+    def continueDestroyBlock(self, x, y, z, sideHit):
         pass
 
-    def tick(self):
+    def stopDestroyBlock(self):
         pass
 
     def render(self, damageTime):
@@ -43,3 +50,15 @@ class GameMode:
 
     def initPlayer(self, player):
         pass
+
+    def tick(self):
+        pass
+
+    def createPlayer(self, level):
+        pass
+
+    def canHurtPlayer(self):
+        return True
+
+    def adjustPlayer(self, player):
+        pass
